declare module 'cirnofw' {
    import * as Discord from 'discord.js';

    export class Client extends Discord.Client {
        readonly name: string;
        readonly commandDirectory: string;
        readonly commandPrefix: string;
        readonly owners: string | string[];
        readonly statusMessage: string;
        readonly logLevel: LogLevel;
        readonly djsDebug: boolean;
        readonly unknownErrorMessage: boolean;
        readonly replyOnCommandCooldown: boolean;
        readonly logCommandUsage: boolean;
        readonly disableDefaultCommands: boolean;
        loader: Loader<any>;
        handler: EventHandler;
        registry: CommandRegistry;
        commands: Discord.Collection<string, Command>;
        aliases: Discord.Collection<string, string>;
        faces: any;
        private readonly _token;
        private _logger;
        private _commandGroups;
        constructor(cirnoOptions: CirnoOptions, clientOptions?: Discord.ClientOptions);
        start(): this;
        setCommandGroups(groups: string[][]): void;
        getCommandGroups(): string[][];
        log(message: string): void;
        warn(message: string): void;
        error(error: any): void;
        runAll(): void;
    }

    export type CirnoOptions = {
        name?: string;
        token: string;
        owners?: string | string[];
        commandDirectory?: string;
        commandPrefix?: string;
        statusMessage?: string;
        logLevel?: LogLevel;
        djsDebug?: boolean;
        unknownCommandError?: boolean;
        replyOnCommandCooldown?: boolean;
        logCommandUsage?: boolean;
        disableDefaultCommands?: boolean;
    };
    export enum LogLevel {
        None = 0,
        Info = 1,
        Warn = 2,
        Debug = 3,
    }

    export type CommandInfo = {
        name: string;
        aliases?: string[];
        group?: string;
        description?: string;
        info?: string;
        ownerOnly?: boolean;
        guildOnly?: boolean;
        argSeparator?: string;
        examples?: string[];
        permissions?: Discord.PermissionResolvable[];
        cooldown?: number;
    };
    export class Command {
        name: string;
        aliases: string[];
        group: string;
        description: string;
        info: string;
        ownerOnly: boolean;
        guildOnly: boolean;
        argSeparator: string;
        examples: string[];
        permissions: Discord.PermissionResolvable[];
        cooldown: number;
        constructor(info?: CommandInfo);
        execute(client: Client, message: Discord.Message, args?: any[]): void;
    }

    export class CommandRegistry {
        private client;
        private groups;
        constructor(client: Client);
        loadGroups(): Promise<Discord.Collection<string, Command[]>>;
        getGroups(): Discord.Collection<string, Command[]>;
    }

    export class EventHandler {
        private client;
        private cooldowns;
        constructor(client: Client);
        events(): void;
        commandHandler(): void;
        processEvents(): void;
    }

    export class Loader<T extends Client> {
        private client;
        private _logger;
        constructor(client: Client);
        loadCommands(): Promise<void>;
    }

    export class Logger {
        private client;
        constructor(client: Client);
        log(message: string): Promise<void>;
        warn(message: string): Promise<void>;
        error(error: any): Promise<void>;
        debug(message: string): Promise<void>;
    }

    global  {
        interface String {
            mockify(): string;
        }
    }
    export class Helper {
        isNullOrWhitespace(input: string): boolean;
    }
    export {};
}
